pub enum NlFormat {
Ascii,
Binary,
}Expand description
Encoding of the body that follows the (always-ASCII) 10-line header.
Variants
Ascii
ASCII g header, every token on its own line.
Binary
Binary b header, opcodes as single bytes, ints as 4-byte LE, doubles
as 8-byte LE, integer-valued numeric constants emitted as s (short)
or l (long) when they fit.